@@ -81,17 +81,6 @@ KHintsSettings::KHintsSettings(KSharedConfig::Ptr kdeglobals)
         updatePortalSetting();
     }
 
-    // try to extract the proper defaults file from a lookandfeel package
-    const QString looknfeel = readConfigValue(cg, QStringLiteral("LookAndFeelPackage"), defaultLookAndFeelPackage).toString();
-    mDefaultLnfConfig = KSharedConfig::openConfig(
-        QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                               QStringLiteral("plasma/look-and-feel/") + defaultLookAndFeelPackage + QStringLiteral("/contents/defaults")));
-    if (looknfeel != defaultLookAndFeelPackage) {
-        mLnfConfig =
-            KSharedConfig::openConfig(QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                                             QStringLiteral("plasma/look-and-feel/") + looknfeel + QStringLiteral("/contents/defaults")));
-    }
-
     const auto cursorBlinkRate = readConfigValue(cg, QStringLiteral("CursorBlinkRate"), 1000).toInt();
     m_hints[QPlatformTheme::CursorFlashTime] = cursorBlinkRate > 0 ? qBound(200, cursorBlinkRate, 2000) : 0; // 0 => no blinking
     m_hints[QPlatformTheme::MouseDoubleClickInterval] = readConfigValue(cg, QStringLiteral("DoubleClickInterval"), 400);
@@ -163,31 +152,7 @@ KHintsSettings::~KHintsSettings()
 QVariant KHintsSettings::readConfigValue(const QString &group, const QString &key, const QVariant &defaultValue)
 {
     KConfigGroup userCg(mKdeGlobals, group);
-    QVariant value = readConfigValue(userCg, key, QString());
-
-    if (!value.isNull()) {
-        return value;
-    }
-
-    if (mLnfConfig) {
-        KConfigGroup lnfCg(mLnfConfig, "kdeglobals");
-        lnfCg = KConfigGroup(&lnfCg, group);
-        if (lnfCg.isValid()) {
-            value = lnfCg.readEntry(key, defaultValue);
-
-            if (!value.isNull()) {
-                return value;
-            }
-        }
-    }
-
-    KConfigGroup lnfCg(mDefaultLnfConfig, "kdeglobals");
-    lnfCg = KConfigGroup(&lnfCg, group);
-    if (lnfCg.isValid()) {
-        return lnfCg.readEntry(key, defaultValue);
-    }
-
-    return defaultValue;
+    return readConfigValue(userCg, key, defaultValue);
 }
 
 QVariant KHintsSettings::readConfigValue(const KConfigGroup &cg, const QString &key, const QVariant &defaultValue) const
@@ -382,8 +347,8 @@ void KHintsSettings::iconChanged(int group)
         return;
     }
 
-    QWidgetList widgets = QApplication::allWidgets();
-    Q_FOREACH (QWidget *widget, widgets) {
+    const QWidgetList widgets = QApplication::allWidgets();
+    for (QWidget *widget : widgets) {
         if (qobject_cast<QToolBar *>(widget) || qobject_cast<QMainWindow *>(widget)) {
             QEvent event(QEvent::StyleChange);
             QApplication::sendEvent(widget, &event);
@@ -477,13 +442,12 @@ void KHintsSettings::loadPalettes()
 
 void KHintsSettings::updateCursorTheme()
 {
-    KConfig config(QStringLiteral("kcminputrc"));
-    KConfigGroup g(&config, "Mouse");
-
-    int size = g.readEntry("cursorSize", 24);
-
 #if HAVE_X11
     if (QX11Info::isPlatformX11()) {
+        KConfig config(QStringLiteral("kcminputrc"));
+        KConfigGroup g(&config, "Mouse");
+
+        int size = g.readEntry("cursorSize", 24);
         const QString theme = g.readEntry("cursorTheme", QString());
         // Note that in X11R7.1 and earlier, calling XcursorSetTheme()
         // with a NULL theme would cause Xcursor to use "default", but
